( cd usr/bin ; rm -rf soffice )
( cd usr/bin ; ln -sf /usr/lib64/ooo-2.3/program/soffice soffice )
( cd usr/lib64 ; rm -rf ooo )
( cd usr/lib64 ; ln -sf ooo-2.3 ooo )
( cd usr/lib64/ooo-2.3/program ; rm -rf uno )
( cd usr/lib64/ooo-2.3/program ; ln -sf unopkg uno )
( cd usr/lib64/ooo-2.3/program ; rm -rf libxmlsec1-nss.so.1 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libxmlsec1-nss.so.1.2.6 libxmlsec1-nss.so.1 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libuno_cppuhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_cppuhelpergcc3.so.3 libuno_cppuhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libportaudio.so.0 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libportaudio.so.0.0.18 libportaudio.so.0 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libcppuhelpergcc3.so.3 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_cppuhelpergcc3.so.3 libcppuhelpergcc3.so.3 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libsalhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libsalhelpergcc3.so.3 libsalhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libuno_salhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_salhelpergcc3.so.3 libuno_salhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libreg.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libreg.so.3 libreg.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libsal.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libsal.so.3 libsal.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libicudata.so.36 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libicudata.so.36.0 libicudata.so.36 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libuno_cppu.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_cppu.so.3 libuno_cppu.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf spadmin )
( cd usr/lib64/ooo-2.3/program ; ln -sf soffice spadmin )
( cd usr/lib64/ooo-2.3/program ; rm -rf libuno_sal.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_sal.so.3 libuno_sal.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libsalhelper3gcc3.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libsalhelpergcc3.so.3 libsalhelper3gcc3.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libicui18n.so.36 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libicui18n.so.36.0 libicui18n.so.36 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libxmlsec1.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libxmlsec1.so.1 libxmlsec1.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libstore.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libstore.so.3 libstore.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libcppuhelper3gcc3.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libcppuhelpergcc3.so.3 libcppuhelper3gcc3.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libcppuhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libcppuhelpergcc3.so.3 libcppuhelpergcc3.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libportaudio.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libportaudio.so.0 libportaudio.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libicule.so.36 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libicule.so.36.0 libicule.so.36 )
( cd usr/lib64/ooo-2.3/program ; rm -rf pkgchk )
( cd usr/lib64/ooo-2.3/program ; ln -sf unopkg pkgchk )
( cd usr/lib64/ooo-2.3/program ; rm -rf libsal.so.3 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_sal.so.3 libsal.so.3 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libcppu.so.3 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_cppu.so.3 libcppu.so.3 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libcppu.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libcppu.so.3 libcppu.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf librmcxt.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf librmcxt.so.3 librmcxt.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libicuuc.so.36 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libicuuc.so.36.0 libicuuc.so.36 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libsalhelpergcc3.so.3 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libuno_salhelpergcc3.so.3 libsalhelpergcc3.so.3 )
( cd usr/lib64/ooo-2.3/program ; rm -rf libxmlsec1-nss.so )
( cd usr/lib64/ooo-2.3/program ; ln -sf libxmlsec1-nss.so.1 libxmlsec1-nss.so )
( cd usr/lib64/ooo-2.3/program ; rm -rf libxmlsec1.so.1 )
( cd usr/lib64/ooo-2.3/program ; ln -sf libxmlsec1.so.1.2.6 libxmlsec1.so.1 )
( cd usr/share/pixmaps ; rm -rf ooo-writer2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-writer2.3.png ooo-writer2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-impress2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-impress2.3.png ooo-impress2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-template2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-template2.3.png ooo-template2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-base2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-base2.3.png ooo-base2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-web2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-web2.3.png ooo-web2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-draw2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-draw2.3.png ooo-draw2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-gulls2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-gulls2.3.png ooo-gulls2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-calc2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-calc2.3.png ooo-calc2.3.png )
( cd usr/share/pixmaps ; rm -rf ooo-math2.3.png )
( cd usr/share/pixmaps ; ln -sf /usr/share/icons/hicolor/48x48/apps/ooo-math2.3.png ooo-math2.3.png )

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database -q usr/share/applications
fi

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor
